# raspa_ase

[![codecov](https://codecov.io/gh/Quantum-Accelerators/raspa_ase/graph/badge.svg?token=id2iXIabYN)](https://codecov.io/gh/Quantum-Accelerators/raspa_ase)
[![DeepSource](https://app.deepsource.com/gh/Quantum-Accelerators/raspa_ase.svg/?label=active+issues&show_trend=false&token=gyXteMXbPx_M-iXaifNiY9wp)](https://app.deepsource.com/gh/Quantum-Accelerators/raspa_ase/)

An Atomic Simulation Environment (ASE) calculator for the [RASPA](https://github.com/iRASPA/RASPA2) molecular simulation code.

## Documentation 📖

<p align="center">
     <a href="https://quantum-accelerators.github.io/raspa_ase/"><b><i>Learn More Here!</i></b></a> 
</p>
